@@ -57,8 +57,7 @@ class WorkflowOptimizer(QWidget):
 
         self._live_update_checkbox = QCheckBox("Live-update")
         self._live_update_checkbox.setToolTip("This updates the segmentation result in the viewer while optimization.\nActivating live-update makes the optimization \nvery slow but potentially nice to look at.")
-        # todo: reactivate checkbox when it's save
-        # self.layout().addWidget(self._live_update_checkbox)
+        self.layout().addWidget(self._live_update_checkbox)
         self.layout().addWidget(vertical_widget(QLabel("Number of iterations"), self.maxiter_select.native))
         self.layout().addWidget(vertical_widget(self._push_button, self._undo_button))
         self.layout().setSpacing(10)
@@ -131,9 +130,6 @@ class WorkflowOptimizer(QWidget):
                 debug_output=True)
 
         # Update progress/status in a separate thread
-        from napari.utils import progress
-        self._progress_reporter = progress(total=self.maxiter_select.value)
-
         @thread_worker
         def status_runner():
             while True:
@@ -141,7 +137,7 @@ class WorkflowOptimizer(QWidget):
                 is_running = self._optimizer.is_running()
                 yield is_running
                 if is_running and not self._optimizer.is_cancelling():
-                    self._push_button.setText("Cancel (" + str(self._iteration_count) + "/" + str(self._maxiter) + ")")
+                    pass
                 else:
                     return
 
@@ -150,10 +146,11 @@ class WorkflowOptimizer(QWidget):
         def yield_progress(is_running):
             #print("Update status")
             if is_running:
-                self._progress_reporter.set_description("Optimization")
+                if not self._optimizer.is_cancelling():
+                    self._push_button.setText("Cancel (" + str(self._iteration_count) + "/" + str(self._maxiter) + ")")
+
                 _, quality = self._optimizer.get_plot()
                 if self._iteration_count != len(quality):
-                    self._progress_reporter.update(len(quality) - self._iteration_count)
                     self._iteration_count = len(quality)
                     self._plot_quality()
                     if self._live_update_checkbox.isChecked():
@@ -166,7 +163,6 @@ class WorkflowOptimizer(QWidget):
             self._optimizer.set_numeric_parameters(best_result)
             self._plot_quality()
             self._push_button.setText("Start optimization again")
-            self._progress_reporter.close()
 
             self._undo_button.setVisible(True)
             self._enable_gui(True)
@@ -207,13 +203,8 @@ class WorkflowOptimizer(QWidget):
         self.layout().addWidget(self._result_plot)
 
     def update_viewer(self):
-        WIDGET_KEY = "magic_gui_widget"
-
         def find_widget(parent, name):
-            if hasattr(parent, name):
-                return getattr(parent, name)
-
-            from napari_pyclesperanto_assistant._gui._category_widget import category_args_numeric
+            from napari_assistant._gui._category_widget import category_args_numeric
             for n in category_args_numeric:
                 if hasattr(parent, n):
                     widget = getattr(parent, n)
